@@ -1,5 +1,7 @@
 """The |pydwf.core.api.analog_impedance| module implements a single class: |AnalogImpedance|."""
 
+from typing import Tuple
+
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -230,11 +232,11 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def probeGet(self) -> tuple[float, float]:
+    def probeGet(self) -> Tuple[float, float]:
         """Get |AnalogImpedance| probe parameters.
 
         Returns:
-            tuple[float, float]:
+            Tuple[float, float]:
                 A two-element tuple: the probe resistance, in Ohms, and the probe capacity, in Farads.
 
         Raises:
@@ -316,11 +318,11 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def compGet(self) -> tuple[float, float, float, float]:
+    def compGet(self) -> Tuple[float, float, float, float]:
         """Get the |AnalogImpedance| measurement computation parameters.
 
         Returns:
-            tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
+            Tuple[float, float, float, float]: The open-circuit resistance, open-circuit reactance,
             short-circuit resistance, and short-circuit reactance (all in Ohms).
 
         Raises:
@@ -344,14 +346,14 @@ class AnalogImpedance(AbstractDwfDeviceSubApi):
         short_reactance = c_short_reactance.value
         return (open_resistance, open_reactance, short_resistance, short_reactance)
 
-    def statusInput(self, channel_index: int) -> tuple[float, float]:
+    def statusInput(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogImpedance| input measurement status.
 
         Parameters:
             channel_index(int): The channel for which to get gain and phase information.
 
         Returns:
-            tuple[float, float]: The gain and phase (in radians) of the current measurement.
+            Tuple[float, float]: The gain and phase (in radians) of the current measurement.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
