@@ -1,5 +1,6 @@
 """The |pydwf.core.api.analog_io| module implements a single class: |AnalogIO|."""
 
+from typing import Tuple
 import ctypes
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -65,7 +66,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def enableInfo(self) -> tuple[bool, bool]:
+    def enableInfo(self) -> Tuple[bool, bool]:
         """Verify if *Master Enable* and/or *Master Enable Status* are supported.
 
         The *Master Enable* is a software switch that enable the |AnalogIO| voltage sources.
@@ -78,7 +79,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         has been triggered.
 
         Returns:
-            tuple[bool, bool]: The tuple elements indicate whether *Master Enable Set* and
+            Tuple[bool, bool]: The tuple elements indicate whether *Master Enable Set* and
             *Master Enable Status*, respectively, are supported by the |AnalogIO| device.
 
         Raises:
@@ -157,7 +158,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         channel_count = c_channel_count.value
         return channel_count
 
-    def channelName(self, channel_index: int) -> tuple[str, str]:
+    def channelName(self, channel_index: int) -> Tuple[str, str]:
         """Return the name (long text) and label (short text, printed on the device) for the
         specified |AnalogIO| channel.
 
@@ -165,7 +166,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             channel_index (int): The channel for which we want to get the name and label.
 
         Returns:
-            tuple[str, str]: The name and label of the channel.
+            Tuple[str, str]: The name and label of the channel.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -201,7 +202,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return c_node_count.value
 
-    def channelNodeName(self, channel_index: int, node_index: int) -> tuple[str, str]:
+    def channelNodeName(self, channel_index: int, node_index: int) -> Tuple[str, str]:
         """Return the node name ("Voltage", "Current", …) and units ("V", "A", …) for the specified |AnalogIO| node.
 
         Parameters:
@@ -209,7 +210,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             node_index (int): The node for which we want to get the name and unit.
 
         Returns:
-            tuple[str, str]: The name and unit of the quantity associated with the node.
+            Tuple[str, str]: The name and unit of the quantity associated with the node.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -253,7 +254,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         analog_io = DwfAnalogIO(c_analog_io.value)
         return analog_io
 
-    def channelNodeSetInfo(self, channel_index: int, node_index: int) -> tuple[float, float, int]:
+    def channelNodeSetInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
         """Return the limits of the value that can be assigned to the specified |AnalogIO| channel node.
 
         Since a node can represent many things (power supply, temperature sensor, etc.),
@@ -267,7 +268,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             node_index (int): The node for which we want to get the currently configured value.
 
         Returns:
-            tuple[float, float, int]: The minimum and maximum values for the specified node's value,
+            Tuple[float, float, int]: The minimum and maximum values for the specified node's value,
             and the number of resolution steps.
 
         Raises:
@@ -330,7 +331,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
         node_value = c_node_value.value
         return node_value
 
-    def channelNodeStatusInfo(self, channel_index: int, node_index: int) -> tuple[float, float, int]:
+    def channelNodeStatusInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
         """Return the range of status values for the specified |AnalogIO| channel node.
 
         Parameters:
@@ -338,7 +339,7 @@ class AnalogIO(AbstractDwfDeviceSubApi):
             node_index (int): The node for which we want to get status information.
 
         Returns:
-            tuple[float, float, int]: The minimum and maximum status values for the specified node,
+            Tuple[float, float, int]: The minimum and maximum status values for the specified node,
             and the number of resolution steps.
 
         Raises:
