@@ -2,6 +2,8 @@
 
 # pylint: disable=too-many-lines
 
+from typing import Tuple, List
+
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -24,11 +26,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
 
     # pylint: disable=too-many-public-methods
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               INSTRUMENT CONTROL                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                               INSTRUMENT CONTROL                                                #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def reset(self, channel_index: int) -> None:
         """Reset the |AnalogOut| instrument.
@@ -79,11 +81,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         status = DwfState(c_status.value)
         return status
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                    CHANNEL COUNT                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                  CHANNEL COUNT                                                  #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def count(self) -> int:
         """Count the number of analog output channels.
@@ -101,20 +103,20 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         channel_count = c_channel_count.value
         return channel_count
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                     PER-CHANNEL STATE MACHINE SETTINGS CONFIGURATION                             #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                PER-CHANNEL STATE MACHINE SETTINGS CONFIGURATION                                 #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def waitInfo(self, channel_index: int) -> tuple[float, float]:
+    def waitInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel valid |Wait:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The range of configurable |Wait:link| state durations, in seconds.
+            Tuple[float, float]: The range of configurable |Wait:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -161,14 +163,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         wait_duration = c_wait_duration.value
         return wait_duration
 
-    def runInfo(self, channel_index: int) -> tuple[float, float]:
+    def runInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel valid |Running:link| state duration range, in seconds.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The range of allowed |Running:link| state durations, in seconds.
+            Tuple[float, float]: The range of allowed |Running:link| state durations, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -274,7 +276,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         repeat_trigger_flag = bool(c_repeat_trigger_flag.value)
         return repeat_trigger_flag
 
-    def repeatInfo(self, channel_index: int) -> tuple[int, int]:
+    def repeatInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get |AnalogOut| repeat count range.
 
         The *repeat count* is the number of times the |AnalogOut| channel will go through the
@@ -284,7 +286,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[int, int]: The range of configurable repeat values.
+            Tuple[int, int]: The range of configurable repeat values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -393,13 +395,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         master_channel_index = c_master_channel_index.value
         return master_channel_index
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                           PER-CHANNEL TRIGGER CONFIGURATION                                      #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                        PER-CHANNEL TRIGGER CONFIGURATION                                        #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get a list of valid |AnalogOut| instrument trigger sources.
 
         Warning:
@@ -408,7 +410,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
-            list[DwfTriggerSource]: The list of DwfTriggerSource values that can be configured.
+            List[DwfTriggerSource]: The list of DwfTriggerSource values that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -494,11 +496,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
         return trigger_slope
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               PER-CHANNEL OUTPUT SETTINGS                                        #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                           PER-CHANNEL OUTPUT SETTINGS                                           #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def modeSet(self, channel_index: int, mode: DwfAnalogOutMode) -> None:
         """Set the |AnalogOut| channel mode (voltage or current).
@@ -533,14 +535,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         mode = DwfAnalogOutMode(c_mode.value)
         return mode
 
-    def idleInfo(self, channel_index: int) -> list[DwfAnalogOutIdle]:
+    def idleInfo(self, channel_index: int) -> List[DwfAnalogOutIdle]:
         """Get the valid |AnalogOut| channel idle settings.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            list[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
+            List[DwfAnalogOutIdle]: A list of options for the channel behavior when idle.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -586,14 +588,14 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         idle = DwfAnalogOutIdle(c_idle.value)
         return idle
 
-    def limitationInfo(self, channel_index: int) -> tuple[float, float]:
+    def limitationInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel limitation range, in Volts or Amps.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The range of limitation values that can be configured.
+            Tuple[float, float]: The range of limitation values that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -640,11 +642,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         limitation = c_limitation.value
         return limitation
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                           PER-CHANNEL MISCELLANEOUS SETTINGS                                     #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                       PER-CHANNEL MISCELLANEOUS SETTINGS                                        #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def customAMFMEnableSet(self, channel_index: int, enable: bool) -> None:
 
@@ -699,20 +701,20 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         enable = bool(c_enable.value)
         return enable
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                  NODE ENUMERATION                                                #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                NODE ENUMERATION                                                 #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def nodeInfo(self, channel_index: int) -> list[DwfAnalogOutNode]:
+    def nodeInfo(self, channel_index: int) -> List[DwfAnalogOutNode]:
         """Get a list of valid |AnalogOut| channel nodes.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            list[DwfAnalogOutNode]: The valid nodes for this channel.
+            List[DwfAnalogOutNode]: The valid nodes for this channel.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -725,11 +727,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         node_info_list = [node for node in DwfAnalogOutNode if node_info_bitset & (1 << node.value)]
         return node_info_list
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                  NODE CONFIGURATION                                              #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                               NODE CONFIGURATION                                                #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def nodeEnableSet(self, channel_index: int, node: DwfAnalogOutNode, enable: bool) -> None:
         """Enabled or disable an |AnalogOut| channel node.
@@ -766,7 +768,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         enable = bool(c_enable.value)
         return enable
 
-    def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> list[DwfAnalogOutFunction]:
+    def nodeFunctionInfo(self, channel_index: int, node: DwfAnalogOutNode) -> List[DwfAnalogOutFunction]:
         """Get the valid waveform shape function options of an |AnalogOut| channel node.
 
         Parameters:
@@ -774,7 +776,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            list[DwfAnalogOutFunction]: The available node waveform shape functions.
+            List[DwfAnalogOutFunction]: The available node waveform shape functions.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -826,7 +828,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         func = DwfAnalogOutFunction(c_func.value)
         return func
 
-    def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodeFrequencyInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get the channel node valid frequency range for an |AnalogOut| channel node, in Hz.
 
         Parameters:
@@ -834,7 +836,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            tuple[float, float]: The range of valid frequencies, in Hz.
+            Tuple[float, float]: The range of valid frequencies, in Hz.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -896,7 +898,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         frequency = c_frequency.value
         return frequency
 
-    def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodeAmplitudeInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get the amplitude range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
@@ -966,7 +968,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         amplitude = c_amplitude.value
         return amplitude
 
-    def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodeOffsetInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get the valid offset range for an |AnalogOut| channel node, in Volts.
 
         Parameters:
@@ -1026,7 +1028,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         offset = c_offset.value
         return offset
 
-    def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodeSymmetryInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get the *symmetry* range for an |AnalogOut| channel node.
 
         The *symmetry* value alters the waveform shape function of the node.
@@ -1040,7 +1042,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            tuple[float, float]: The range of valid symmetry settings.
+            Tuple[float, float]: The range of valid symmetry settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1106,7 +1108,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         symmetry = c_symmetry.value
         return symmetry
 
-    def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodePhaseInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get the valid phase range for an |AnalogOut| channel node, in degrees.
 
         Parameters:
@@ -1114,7 +1116,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            tuple[float, float]: The range of valid channel node phase values, in degrees.
+            Tuple[float, float]: The range of valid channel node phase values, in degrees.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1176,13 +1178,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         phase = c_phase.value
         return phase
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                NODE DATA MANAGEMENT                                              #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              NODE DATA MANAGEMENT                                               #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[float, float]:
+    def nodeDataInfo(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[float, float]:
         """Get data range for an |AnalogOut| channel node, in samples.
 
         Parameters:
@@ -1190,7 +1192,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            tuple[float, float]: The range of valid values.
+            Tuple[float, float]: The range of valid values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1232,7 +1234,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> tuple[int, int, int]:
+    def nodePlayStatus(self, channel_index: int, node: DwfAnalogOutNode) -> Tuple[int, int, int]:
         """Get the play status for an |AnalogOut| channel node.
 
         Parameters:
@@ -1240,7 +1242,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             node (DwfAnalogOutNode): The channel node.
 
         Returns:
-            tuple[int, int, int]: The *free*, *lost*, and *corrupted* status counts, in samples.
+            Tuple[int, int, int]: The *free*, *lost*, and *corrupted* status counts, in samples.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1282,11 +1284,11 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                            CARRIER CONFIGURATION (OBSOLETE)                                      #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                        CARRIER CONFIGURATION (OBSOLETE)                                         #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def enableSet(self, channel_index: int, enable: bool) -> None:
         """Enable or disable the specified |AnalogOut| channel.
@@ -1319,7 +1321,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            bool: The enable state of the channel.
+            bool: The 'enable' state of the channel.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1331,7 +1333,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         enable = bool(c_enable.value)
         return enable
 
-    def functionInfo(self, channel_index: int) -> list[DwfAnalogOutFunction]:
+    def functionInfo(self, channel_index: int) -> List[DwfAnalogOutFunction]:
         """Get the |AnalogOut| channel waveform shape function info.
 
         Warning:
@@ -1340,7 +1342,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             Use the :py:meth:`nodeFunctionInfo` method instead.
 
         Returns:
-            list[DwfAnalogOutFunction]: The valid waveform shape functions.
+            List[DwfAnalogOutFunction]: The valid waveform shape functions.
 
         Parameters:
             channel_index (int): The |AnalogOut| channel.
@@ -1400,7 +1402,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         func = DwfAnalogOutFunction(c_func.value)
         return func
 
-    def frequencyInfo(self, channel_index: int) -> tuple[float, float]:
+    def frequencyInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel valid frequency range, in Hz.
 
         Warning:
@@ -1412,7 +1414,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The valid frequency range, in Hz.
+            Tuple[float, float]: The valid frequency range, in Hz.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1469,7 +1471,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         frequency = c_frequency.value
         return frequency
 
-    def amplitudeInfo(self, channel_index: int) -> tuple[float, float]:
+    def amplitudeInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel amplitude range info.
 
         Warning:
@@ -1538,7 +1540,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         amplitude = c_amplitude.value
         return amplitude
 
-    def offsetInfo(self, channel_index: int) -> tuple[float, float]:
+    def offsetInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel offset range info, in Volts.
 
         Warning:
@@ -1550,7 +1552,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The valid range of offset values, in Volts.
+            Tuple[float, float]: The valid range of offset values, in Volts.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1607,7 +1609,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         offset = c_offset.value
         return offset
 
-    def symmetryInfo(self, channel_index: int) -> tuple[float, float]:
+    def symmetryInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel symmetry setting range.
 
         Warning:
@@ -1619,7 +1621,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The range of valid symmetry settings.
+            Tuple[float, float]: The range of valid symmetry settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1676,7 +1678,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         symmetry = c_symmetry.value
         return symmetry
 
-    def phaseInfo(self, channel_index: int) -> tuple[float, float]:
+    def phaseInfo(self, channel_index: int) -> Tuple[float, float]:
         """Get the |AnalogOut| channel phase range, in degrees.
 
         Warning:
@@ -1688,7 +1690,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[float, float]: The range of valid phase values, in degrees.
+            Tuple[float, float]: The range of valid phase values, in degrees.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1745,13 +1747,13 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         phase = c_phase.value
         return phase
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                       CARRIER NODE DATA MANAGEMENT (OBSOLETE)                                    #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                     CARRIER NODE DATA MANAGEMENT (OBSOLETE)                                     #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def dataInfo(self, channel_index: int) -> tuple[int, int]:
+    def dataInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get the |AnalogOut| channel data buffer range.
 
         Warning:
@@ -1763,7 +1765,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[int, int]: The data range.
+            Tuple[int, int]: The data range.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -1803,7 +1805,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def playStatus(self, channel_index: int) -> tuple[int, int, int]:
+    def playStatus(self, channel_index: int) -> Tuple[int, int, int]:
         """Get the |AnalogOut| channel playback status, in samples.
 
         Warning:
@@ -1815,7 +1817,7 @@ class AnalogOut(AbstractDwfDeviceSubApi):
             channel_index (int): The |AnalogOut| channel.
 
         Returns:
-            tuple[int, int, int]: The playback status.
+            Tuple[int, int, int]: The playback status.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
