@@ -2,6 +2,8 @@
 
 # pylint: disable=too-many-lines
 
+from typing import Tuple, List
+
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -25,11 +27,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
 
     # pylint: disable=too-many-public-methods
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               INSTRUMENT CONTROL                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                               INSTRUMENT CONTROL                                                #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def reset(self) -> None:
         """Reset the |DigitalIn| instrument parameters to default values.
@@ -95,17 +97,17 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         status = DwfState(c_status.value)
         return status
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                 STATUS VARIABLES                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                STATUS VARIABLES                                                 #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def statusTime(self) -> tuple[int, int, int]:
+    def statusTime(self) -> Tuple[int, int, int]:
         """Get the timestamp of the current status information.
 
         Returns:
-            tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
+            Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
             The first element is the POSIX second, the second and third element are the numerator and denominator,
             respectively, of the fractional part of the second.
 
@@ -198,11 +200,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         index_write = c_index_write.value
         return index_write
 
-    def statusRecord(self) -> tuple[int, int, int]:
+    def statusRecord(self) -> Tuple[int, int, int]:
         """Get the recording status.
 
         Returns:
-            tuple[int, int, int]: A three-element tuple containing the counts for
+            Tuple[int, int, int]: A three-element tuple containing the counts for
             *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
@@ -223,11 +225,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         data_corrupt = c_data_corrupt.value
         return (data_free, data_lost, data_corrupt)
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               STATUS DATA RETRIEVAL                                              #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              STATUS DATA RETRIEVAL                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def statusData(self, count_bytes: int) -> np.ndarray:
         """Retrieve the acquired data samples from the |DigitalIn| instrument.
@@ -285,11 +287,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return noise
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                            ACQUISITION TIMING SETTINGS                                           #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                           ACQUISITION TIMING SETTINGS                                           #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def internalClockInfo(self) -> float:
         """Get the |DigitalIn| internal clock frequency, in Hz.
@@ -307,11 +309,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         frequency = c_frequency.value
         return frequency
 
-    def clockSourceInfo(self) -> list[DwfDigitalInClockSource]:
+    def clockSourceInfo(self) -> List[DwfDigitalInClockSource]:
         """Get a list of valid clock sources for the |DigitalIn| instrument.
 
         Returns:
-            list[DwfDigitalInClockSource]: A list of valid clock sources.
+            List[DwfDigitalInClockSource]: A list of valid clock sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -402,17 +404,17 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         divider = c_divider.value
         return divider
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                ACQUISITION SETTINGS                                              #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              ACQUISITION SETTINGS                                               #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def acquisitionModeInfo(self) -> list[DwfAcquisitionMode]:
+    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
         """Get a list of valid |DigitalIn| instrument acquisition modes.
 
         Returns:
-            list[DwfAcquisitionMode]: A list of valid acquisition modes for the |DigitalIn| instrument.
+            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |DigitalIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -564,11 +566,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         buffer_size = c_buffer_size.value
         return buffer_size
 
-    def sampleModeInfo(self) -> list[DwfDigitalInSampleMode]:
+    def sampleModeInfo(self) -> List[DwfDigitalInSampleMode]:
         """Get the valid |DigitalIn| instrument sample modes.
 
         Returns:
-            list[DwfDigitalInSampleMode]: A list of valid sample modes.
+            List[DwfDigitalInSampleMode]: A list of valid sample modes.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -688,13 +690,13 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         samples_before_trigger = c_samples_before_trigger.value
         return samples_before_trigger
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                TRIGGER CONFIGURATION                                             #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              TRIGGER CONFIGURATION                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get the valid |DigitalIn| instrument trigger sources.
 
         Warning:
@@ -703,7 +705,7 @@ class DigitalIn(AbstractDwfDeviceSubApi):
             Use the generic :py:meth:`DeviceControl.triggerInfo()` method instead.
 
         Returns:
-            list[DwfTriggerSource]: A list of valid trigger sources.
+            List[DwfTriggerSource]: A list of valid trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -822,11 +824,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         samples_after_trigger = c_samples_after_trigger.value
         return samples_after_trigger
 
-    def triggerAutoTimeoutInfo(self) -> tuple[float, float, int]:
+    def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
         """Get |DigitalIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
-            tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
+            Tuple[float, float, int]: The range and number of steps of the auto-timeout setting.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -879,20 +881,20 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         auto_timeout = c_auto_timeout.value
         return auto_timeout
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               TRIGGER DETECTOR CONFIGURATION                                     #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                         TRIGGER DETECTOR CONFIGURATION                                          #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerInfo(self) -> tuple[int, int, int, int]:
+    def triggerInfo(self) -> Tuple[int, int, int, int]:
         """Get |DigitalIn| detector trigger info.
 
         Return the pins that support the different types of triggering. Each integer is a bitmask, representing pins
         that can be used as *low level*, *high level*, *rising edge*, and *falling edge* triggers.
 
         Returns:
-            tuple[int, int, int, int]: Digital pins that can be used as *low level*, *high level*, *rising edge*,
+            Tuple[int, int, int, int]: Digital pins that can be used as *low level*, *high level*, *rising edge*,
             and *falling edge* triggers, respectively.
 
         Raises:
@@ -944,11 +946,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerGet(self) -> tuple[int, int, int, int]:
+    def triggerGet(self) -> Tuple[int, int, int, int]:
         """Get the configured |DigitalIn| trigger detector settings.
 
         Returns:
-            tuple[int, int, int, int]: The currently configured *level_low*, *level_high*, *edge_rise*,
+            Tuple[int, int, int, int]: The currently configured *level_low*, *level_high*, *edge_rise*,
             and *edge_fall* settings.
 
         Raises:
@@ -1044,8 +1046,8 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         Todo:
             Figure out what this setting does.
 
-        Configure the deserializer. The bits are left shifted. the mask and value should be specified according to this,
-        in MSB-first order.
+        Configure the deserializer. The bits are left shifted.
+        The mask and value should be specified accordingly, in MSB-first order.
 
         Parameters:
             pin (int): The pin to be deserialized.
@@ -1060,11 +1062,11 @@ class DigitalIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                   MISCELLANEOUS SETTINGS                                         #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                             MISCELLANEOUS SETTINGS                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def mixedSet(self, enable: bool) -> None:
         """Set mixed state.
