@@ -1,5 +1,6 @@
 """The |pydwf.core.api.digital_out| module implements a single class: |DigitalOut|."""
 
+from typing import Tuple, List
 import ctypes
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -24,11 +25,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
 
     # pylint: disable=too-many-public-methods
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               INSTRUMENT CONTROL                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                               INSTRUMENT CONTROL                                                #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def reset(self) -> None:
         """Reset the |DigitalOut| instrument.
@@ -71,11 +72,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         status_ = DwfState(c_status.value)
         return status_
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                    CHANNEL COUNT                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                  CHANNEL COUNT                                                  #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def count(self) -> int:
         """Get the |DigitalOut| instrument channel (digital pin) count.
@@ -93,17 +94,17 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         channel_count = c_channel_count.value
         return channel_count
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                 STATE MACHINE SETTINGS                                           #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                             STATE MACHINE SETTINGS                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def waitInfo(self) -> tuple[float, float]:
+    def waitInfo(self) -> Tuple[float, float]:
         """Get the |DigitalOut| instrument range for the |Wait:link| state duration, in seconds.
 
         Returns:
-            tuple[float, float]: A tuple containing the minimal and maximal configurable |Wait:link| state duration,
+            Tuple[float, float]: A tuple containing the minimal and maximal configurable |Wait:link| state duration,
             in seconds.
 
         Raises:
@@ -147,11 +148,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         wait_duration = c_wait_duration.value
         return wait_duration
 
-    def runInfo(self) -> tuple[float, float]:
+    def runInfo(self) -> Tuple[float, float]:
         """Get the |DigitalOut| instrument range for the |Running:link| state duration, in seconds.
 
         Returns:
-            tuple[float, float]: A tuple containing the minimal and maximal |Running:link| state duration, in seconds.
+            Tuple[float, float]: A tuple containing the minimal and maximal |Running:link| state duration, in seconds.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -252,11 +253,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         repeat_trigger_flag = bool(c_repeat_trigger.value)
         return repeat_trigger_flag
 
-    def repeatInfo(self) -> tuple[int, int]:
+    def repeatInfo(self) -> Tuple[int, int]:
         """Get the |DigitalOut| minimal and maximal repeat count for pulse-sequence runs.
 
         Returns:
-            tuple[int, int]: A tuple containing the minimal and maximal repeat count for
+            Tuple[int, int]: A tuple containing the minimal and maximal repeat count for
             digital-out pulse-sequence runs.
 
         Raises:
@@ -320,13 +321,13 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         repeat_status = c_repeat_status.value
         return repeat_status
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                 TRIGGER CONFIGURATION                                            #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              TRIGGER CONFIGURATION                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get the valid |DigitalOut| trigger sources.
 
         Warning:
@@ -335,7 +336,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
             Use the generic DeviceControl.triggerInfo() method instead.
 
         Returns:
-            list[DwfTriggerSource]: A list of valid the trigger sources.
+            List[DwfTriggerSource]: A list of valid the trigger sources.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -407,11 +408,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         trigger_slope = DwfTriggerSlope(c_trigger_slope.value)
         return trigger_slope
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                    OUTPUT SETTINGS                                               #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                 OUTPUT SETTINGS                                                 #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def enableSet(self, channel_index: int, enable_flag: bool) -> None:
         """Enable or disable a |DigitalOut| channel (pin).
@@ -446,11 +447,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         enable_flag = bool(c_enable_flag.value)
         return enable_flag
 
-    def outputInfo(self, channel_index: int) -> list[DwfDigitalOutOutput]:
+    def outputInfo(self, channel_index: int) -> List[DwfDigitalOutOutput]:
         """Get valid |DigitalOut| output choices (e.g. Push/Pull, tristate).
 
         Returns:
-            list[DwfDigitalOutOutput]: A list of valid output settings.
+            List[DwfDigitalOutOutput]: A list of valid output settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -496,7 +497,7 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         output_value = DwfDigitalOutOutput(c_output_value.value)
         return output_value
 
-    def typeInfo(self, channel_index: int) -> list[DwfDigitalOutType]:
+    def typeInfo(self, channel_index: int) -> List[DwfDigitalOutType]:
         """Get a list of valid |DigitalOut| output channel types.
 
         Returns:
@@ -546,11 +547,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         output_type = DwfDigitalOutType(c_output_type.value)
         return output_type
 
-    def idleInfo(self, channel_index: int) -> list[DwfDigitalOutIdle]:
+    def idleInfo(self, channel_index: int) -> List[DwfDigitalOutIdle]:
         """Get valid |DigitalOut| idle output values.
 
         Returns:
-            list[DwfDigitalOutIdle]: A list of valid idle output values.
+            List[DwfDigitalOutIdle]: A list of valid idle output values.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -596,11 +597,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         idle_mode = DwfDigitalOutIdle(c_idle_mode.value)
         return idle_mode
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               OUTPUT PATTERN TIMING DEFINITION                                   #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                        OUTPUT PATTERN TIMING DEFINITION                                         #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def internalClockInfo(self) -> float:
         """Get the |DigitalOut| instrument clock frequency.
@@ -618,11 +619,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         internal_clock_frequency = c_internal_clock_frequency.value
         return internal_clock_frequency
 
-    def dividerInfo(self, channel_index: int) -> tuple[int, int]:
+    def dividerInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get the |DigitalOut| divider value range.
 
         Returns:
-            tuple[int, int]: The range of valid divider settings.
+            Tuple[int, int]: The range of valid divider settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -706,14 +707,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         divider_init = c_divider_init.value
         return divider_init
 
-    def counterInfo(self, channel_index: int) -> tuple[int, int]:
+    def counterInfo(self, channel_index: int) -> Tuple[int, int]:
         """Get the |DigitalOut| counter value range.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            tuple[int, int]: The range of valid counter settings.
+            Tuple[int, int]: The range of valid counter settings.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -746,14 +747,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def counterGet(self, channel_index: int) -> tuple[int, int]:
+    def counterGet(self, channel_index: int) -> Tuple[int, int]:
         """Get the |DigitalOut| counter durations for both the low and high signal output levels.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            tuple[int, int]: The number of cycles the signal should be Low, High.
+            Tuple[int, int]: The number of cycles the signal should be Low, High.
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
@@ -785,14 +786,14 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def counterInitGet(self, channel_index: int) -> tuple[bool, int]:
+    def counterInitGet(self, channel_index: int) -> Tuple[bool, int]:
         """Get the |DigitalOut| initial signal value and initial counter value.
 
         Parameters:
             channel_index (int): The digital pin.
 
         Returns:
-            tuple [bool, int]: Whether to start High (True) or Low (False),
+            Tuple [bool, int]: Whether to start High (True) or Low (False),
             and the initial counter setting.
 
         Raises:
@@ -810,11 +811,11 @@ class DigitalOut(AbstractDwfDeviceSubApi):
         counter_init = c_counter_init.value
         return (high, counter_init)
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                      DATA PLAYBACK                                               #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                  DATA PLAYBACK                                                  #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def dataInfo(self, channel_index: int) -> int:
         """Return the maximum buffer size for the specified |DigitalOut| channel,
