@@ -88,7 +88,7 @@ class DwfEnumFilter(_FixReprMethod, enum.Flag):
     AXI = 0x00000004
     """Enumerate AXI devices (used when running on an ADP 3x50 device)."""
 
-    Remote   = 0x10000000
+    Remote = 0x10000000
     """Enumerate remote devices (0x10000000)."""
 
     Audio = 0x20000000
@@ -212,9 +212,6 @@ class DwfDeviceVersion(_FixReprMethod, enum.Enum):
     Note:
         The device revision list given here is not complete; it does not cover all devices.
 
-        Additionally, the enumeration values :py:attr:`EExplorerC` and :py:attr:`DiscoveryB`
-        have identical integer values (2).
-
     In the C API, this type is called 'DEVVER', and it is represented as an *int*.
     """
 
@@ -360,7 +357,8 @@ class DwfState(_FixReprMethod, enum.Enum):
     * |DigitalOut|
     * |AnalogImpedance|
 
-    This type is used to return the current state from their *status()* methods.
+    This type is used to return the current state from their *status()* methods: |AnalogIn.status:link|,
+    |AnalogOut.status:link|, |DigitalIn.status:link|, |DigitalOut.status:link|, and |AnalogImpedance.status:link|.
 
     Note:
         The enumeration values :py:attr:`Triggered` and :py:attr:`Running` have identical integer values (3).
@@ -497,7 +495,8 @@ class DwfAcquisitionMode(_FixReprMethod, enum.Enum):
     """Perform a single buffer acquisition.
 
     Re-arm the instrument for the next capture after the data is fetched to the host
-    using the instrument-specific *Status()* method.
+    using the instrument-specific *status()* method: |AnalogIn.status:link| or
+    |DigitalIn.status:link|.
 
     Note:
         The difference with the :py:attr:`Single1` mode is unclear.
@@ -846,7 +845,8 @@ class DwfAnalogIO(_FixReprMethod, enum.Enum):
     """
 
     Undocumented = 0
-    """This value is returned in Analog Pro devices when using 3.16.3 of the DWF library. That is probably a bug."""
+    """This value was returned in Analog Discovery Pro devices when using 3.16.3 of the DWF library.
+       This was a bug that was subsequently fixed."""
 
     Enable = 1
     """The node represent an on/off switch."""
