@@ -120,7 +120,7 @@ class DwfLibrary:
 
         function_signatures = dwf_function_signatures(typespec_ctypes)
 
-        for (name, restype, argtypes, _obsolete_flag) in function_signatures:
+        for (name, restype, argtypes, UNUSED_obsolete_flag) in function_signatures:
             argtypes = [argtype for (argname, argtype) in argtypes]
             try:
                 func = getattr(lib, name)
